@@ -282,7 +282,7 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
 #        parent.plone_utils.addPortalMessage(_(u'AAA'))
 #        cancel_url = '%s?portal_status_message=%s'%(parent_url, self.getCancel_message())
         cancel_url = '%s/@@verkkomaksut-canceled' %(self.absolute_url())
-        notify_url = '%s/verkkomaksutnotify' % (self.absolute_url())
+        notify_url = '%s/@@verkkomaksut-notify' % (self.absolute_url())
 #        notify_url = '%s/verkkomaksutnotify%s' % (self.absolute_url(), query)
         RETURN_ADDRESS = return_url
         CANCEL_ADDRESS = cancel_url
